@@ -19,13 +19,13 @@
  ***************************************************************************/
 #include "brightnesschooserimpl.h"
 
-#include <ntqprocess.h>
-#include <ntqslider.h>
-#include <ntqlabel.h>
-#include <ntqmessagebox.h>
+#include <tqprocess.h>
+#include <tqslider.h>
+#include <tqlabel.h>
+#include <tqmessagebox.h>
 #include <kdebug.h>
-#include <ntqevent.h>
-#include <ntqregexp.h>
+#include <tqevent.h>
+#include <tqregexp.h>
 
 #include "preferences.h"
 
