@@ -26,7 +26,7 @@
 #endif
 
 #include <kpanelapplet.h>
-#include <ntqstring.h>
+#include <tqstring.h>
 #include <tdeconfig.h>
 
 class TDEPopupMenu;
